@@ -72,7 +72,7 @@ public:
 
     void addAction(QAction *action, Qt::ToolButtonStyle style = Qt::ToolButtonIconOnly)
     {
-        auto *button = new QToolButton;
+        auto button = new QToolButton;
         button->setDefaultAction(action);
         button->setToolButtonStyle(style);
         button->setAutoRaise(true);
@@ -83,7 +83,7 @@ public:
 
     void addSeparator()
     {
-        mLayout->addSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+        mLayout->addSpacing(QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     }
 
     void addStretch()
@@ -97,7 +97,7 @@ public:
     }
 
 private:
-    QBoxLayout *mLayout;
+    QBoxLayout *const mLayout;
 };
 
 FullScreenContent::FullScreenContent(QObject *parent, GvCore *gvCore)
@@ -116,7 +116,7 @@ void FullScreenContent::init(KActionCollection *actionCollection, QWidget *autoH
     // mAutoHideContainer
     mAutoHideContainer = new FullScreenBar(autoHideParentWidget);
     mAutoHideContainer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    auto *layout = new QVBoxLayout(mAutoHideContainer);
+    auto layout = new QVBoxLayout(mAutoHideContainer);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 
@@ -135,17 +135,17 @@ void FullScreenContent::init(KActionCollection *actionCollection, QWidget *autoH
     mToolBar = new FullScreenToolBar(mContent);
 
 #define addAction(name) mToolBar->addAction(actionCollection->action(name))
-    addAction("toggle_sidebar");
+    addAction(QStringLiteral("toggle_sidebar"));
     mToolBar->addSeparator();
-    addAction("browse");
-    addAction("view");
+    addAction(QStringLiteral("browse"));
+    addAction(QStringLiteral("view"));
     mToolBar->addSeparator();
-    addAction("go_previous");
-    addAction("toggle_slideshow");
-    addAction("go_next");
+    addAction(QStringLiteral("go_previous"));
+    addAction(QStringLiteral("toggle_slideshow"));
+    addAction(QStringLiteral("go_next"));
     mToolBar->addSeparator();
-    addAction("rotate_left");
-    addAction("rotate_right");
+    addAction(QStringLiteral("rotate_left"));
+    addAction(QStringLiteral("rotate_right"));
 #undef addAction
     mToolBarShadow = new ShadowFilter(mToolBar);
 
@@ -164,7 +164,7 @@ void FullScreenContent::init(KActionCollection *actionCollection, QWidget *autoH
     mInformationContainer->setAutoFillBackground(true);
     mInformationContainer->setBackgroundRole(QPalette::Mid);
     mInformationContainerShadow = new ShadowFilter(mInformationContainer);
-    auto *hLayout = new QHBoxLayout(mInformationContainer);
+    auto hLayout = new QHBoxLayout(mInformationContainer);
     hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->addWidget(mInformationLabel);
     hLayout->addWidget(mDocumentCountLabel);
@@ -172,7 +172,7 @@ void FullScreenContent::init(KActionCollection *actionCollection, QWidget *autoH
     // Thumbnail bar
     mThumbnailBar = new ThumbnailBarView(mContent);
     mThumbnailBar->setThumbnailScaleMode(ThumbnailView::ScaleToSquare);
-    auto *delegate = new ThumbnailBarItemDelegate(mThumbnailBar);
+    auto delegate = new ThumbnailBarItemDelegate(mThumbnailBar);
     mThumbnailBar->setItemDelegate(delegate);
     mThumbnailBar->setSelectionMode(QAbstractItemView::ExtendedSelection);
     // Calculate minimum bar height to give mInformationLabel exactly two lines height
@@ -236,7 +236,7 @@ void FullScreenContent::updateInformationLabel()
             valueList << value;
         }
     }
-    QString text = valueList.join(i18nc("@item:intext fullscreen meta info separator", ", "));
+    const QString text = valueList.join(i18nc("@item:intext fullscreen meta info separator", ", "));
 
     mInformationLabel->setText(text);
 }
@@ -296,7 +296,7 @@ void FullScreenContent::updateLayout()
     if (GwenviewConfig::showFullScreenThumbnails()) {
         mRightToolBar->setDirection(QBoxLayout::TopToBottom);
 
-        auto *layout = new QHBoxLayout(mContent);
+        auto layout = new QHBoxLayout(mContent);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         QVBoxLayout *vLayout;
@@ -340,7 +340,7 @@ void FullScreenContent::updateLayout()
     } else {
         mRightToolBar->setDirection(QBoxLayout::RightToLeft);
 
-        auto *layout = new QHBoxLayout(mContent);
+        auto layout = new QHBoxLayout(mContent);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         layout->addWidget(mToolBar);
@@ -405,8 +405,8 @@ void FullScreenContent::createOptionsAction()
 void FullScreenContent::updateSlideShowIntervalLabel()
 {
     Q_ASSERT(mConfigWidget);
-    int value = mConfigWidget->mSlideShowIntervalSlider->value();
-    QString text = formatSlideShowIntervalText(value);
+    const int value = mConfigWidget->mSlideShowIntervalSlider->value();
+    const QString text = formatSlideShowIntervalText(value);
     mConfigWidget->mSlideShowIntervalLabel->setText(text);
 }
 
@@ -426,7 +426,7 @@ void FullScreenContent::showOptionsMenu()
 
     // Put widget in a menu
     QMenu menu;
-    auto *action = new QWidgetAction(&menu);
+    auto action = new QWidgetAction(&menu);
     action->setDefaultWidget(widget);
     menu.addAction(action);
 
