@@ -68,7 +68,6 @@ MprisMediaPlayer2Player::MprisMediaPlayer2Player(const QString &objectDBusPath,
     connect(mContextManager, &ContextManager::currentUrlChanged, this, &MprisMediaPlayer2Player::onCurrentUrlChanged);
     connect(mSlideShow->randomAction(), &QAction::toggled, this, &MprisMediaPlayer2Player::onRandomActionToggled);
     connect(mToggleSlideShowAction, &QAction::changed, this, &MprisMediaPlayer2Player::onToggleSlideShowActionChanged);
-    connect(mFullScreenAction, &QAction::toggled, this, &MprisMediaPlayer2Player::onFullScreenActionToggled);
     connect(mNextAction, &QAction::changed, this, &MprisMediaPlayer2Player::onNextActionChanged);
     connect(mPreviousAction, &QAction::changed, this, &MprisMediaPlayer2Player::onPreviousActionChanged);
 }
@@ -77,11 +76,7 @@ MprisMediaPlayer2Player::~MprisMediaPlayer2Player() = default;
 
 bool MprisMediaPlayer2Player::updatePlaybackStatus()
 {
-    const QString newStatus = (!mSlideShowEnabled || !mFullScreenAction->isChecked()) ? QStringLiteral("Stopped")
-        : mSlideShow->isRunning()                                                     ? QStringLiteral("Playing")
-                                                                                      :
-                                  /* else */
-        QStringLiteral("Paused");
+    const QString newStatus = mSlideShow->isRunning() ? QStringLiteral("Playing") : QStringLiteral("Stopped");
 
     const bool changed = (newStatus != mPlaybackStatus);
     if (changed) {
@@ -263,7 +258,7 @@ void MprisMediaPlayer2Player::onMetaInfoUpdated()
         // as images can be added/removed during a running slideshow
         // To allow some bidrectional mapping, convert the url to base64 to encode it for
         // matching the D-Bus object path spec
-        const QString slideId = QString::fromLatin1(url.toString().toUtf8().toBase64(QByteArray::OmitTrailingEquals));
+        const QString slideId = QString::fromLatin1(url.toString().toUtf8().toBase64(QByteArray::OmitTrailingEquals).replace('+', ""));
         const QDBusObjectPath trackId(QStringLiteral("/org/kde/gwenview/imagelist/") + slideId);
         updatedMetaData.insert(QStringLiteral("mpris:trackid"), QVariant::fromValue<QDBusObjectPath>(trackId));
 
@@ -311,16 +306,6 @@ void MprisMediaPlayer2Player::onRandomActionToggled(bool checked)
     signalPropertyChange(QStringLiteral("Shuffle"), checked);
 }
 
-void MprisMediaPlayer2Player::onFullScreenActionToggled()
-{
-    if (!updatePlaybackStatus()) {
-        return;
-    }
-
-    signalPropertyChange(QStringLiteral("Position"), position());
-    signalPropertyChange(QStringLiteral("PlaybackStatus"), mPlaybackStatus);
-}
-
 void MprisMediaPlayer2Player::onToggleSlideShowActionChanged()
 {
     const bool isEnabled = mToggleSlideShowAction->isEnabled();
